pandas.option_context
=====================

.. currentmodule:: pandas

.. autoclass:: option_context

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      




   

